@@ -13,7 +13,6 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
-
 import sys
 import time
 import random
@@ -379,12 +378,13 @@ class FocusRenderer(BaseRenderer):
     A Renderer that takes an image and randomly spreads the characters around the screen.
     The characters are then pulled to the middle of the screen
     """
-    def __init__(self, screen, frames, time, img, effect_type="static", background=" ", transparent=False, start_frame=0):
+    def __init__(self, screen, frames, time, img, effect_type="static", background=" ", transparent=False, start_frame=0, reverse=False):
         super(FocusRenderer, self).__init__(screen, frames, time, effect_type, background, transparent)
         self.background        = background if background else " "
         self.transparent       = transparent if transparent else False
         self.img               = img
-        self.start_frame       = 0
+        self.start_frame       = start_frame
+        self.reverse           = reverse
         if self.img: self._set_img_attributes()
 
     def _set_img_attributes(self):
@@ -397,16 +397,29 @@ class FocusRenderer(BaseRenderer):
         self.img_x_start     = (self.width - len(self.img[0])) // 2
         self.current_img_x   = self.img_x_start
         self.current_img_y   = self.img_y_start
-        self.start_board     = [[[random.randint(0, self.width - 1), random.randint(0, self.height - 1), self.img[y][x], (x, y)] for x in range(self.img_width)] for y in range(self.img_height)]
-        self.current_board   = [[[self.start_board[y][x][0], self.start_board[y][x][1], self.img[y][x], (x, y)] for x in range(self.img_width)] for y in range(self.img_height)]
-        self.end_board       = [[[self.img_x_start + x, self.img_y_start + y, self.img[y][x], (x, y)] for x in range(self.img_width)] for y in range(self.img_height)]
+        self.start_board     = [[[random.randint(0, self.width - 1), random.randint(0, self.height - 1), self.img[y][x], (x, y)] 
+                                  for x in range(self.img_width)] 
+                                  for y in range(self.img_height)]
+        self.current_board   = [[[self.start_board[y][x][0], self.start_board[y][x][1], self.img[y][x], (x, y)] 
+                                  for x in range(self.img_width)]
+                                  for y in range(self.img_height)]
+        self.end_board       = [[[self.img_x_start + x, self.img_y_start + y, self.img[y][x], (x, y)] 
+                                  for x in range(self.img_width)] 
+                                  for y in range(self.img_height)]
         self.direction_board = [[[-1 if (self.end_board[y][x][0] - self.current_board[y][x][0]) < 0 else 1,
                                   -1 if (self.end_board[y][x][1] - self.current_board[y][x][1]) < 0 else 1]
                                   for x in range(self.img_width)] for y in range(self.img_height)]
 
+    def update_reverse(self, reverse):
+        """
+        Function to update whether or not to reverse the Focus
+        :param reverse: True / False
+        """
+        self.reverse = reverse
+
     def update_start_frame(self, frame_number):
         """
-        Updates the frame at which the Focus Effeect should start
+        Updates the frame at which the Focus Effect should start
         :param frame_number: Frame to start
         """
         self.start_frame = frame_number
@@ -444,5 +457,5 @@ class FocusRenderer(BaseRenderer):
                 self.image_buffer.clear_buffer(val=None)
                 for row in self.current_board:
                     for value in row:
-                        self.image_buffer.put_char(value[0], value[1], value[2])
+                        self.image_buffer.put_char(value[0], value[1], value[2], transparent=self.transparent)
             
\ No newline at end of file
