@@ -7,11 +7,13 @@ import pyfiglet
 def demo(screen, img, frames, time, effect_type, background, transparent):
     
     # CREATE THE RENDERER
-    renderer = CenterRenderer(screen, frames, time, img, effect_type, background, transparent)
+    renderer = FocusRenderer(screen, frames, time, img, effect_type, background, transparent, start_frame=100)
 
     # SET EFFECT ATTRIBUTES
-    renderer.effect.update_color(color=True, characters=True)
+    renderer.effect.update_color_properties(color=True, characters=True, random_color=True)
+    renderer.effect.update_grey_scale_size(16)
     renderer.update_smart_transparent(True)
+    renderer.effect.update_info_visibility(True)
 
     # RUN THE ANIMATION
     renderer.run(end_message=False)
@@ -22,7 +24,7 @@ def demo(screen, img, frames, time, effect_type, background, transparent):
 
 
 def main():
-    image = images.get_image("BRUH")
+    image = images.text_to_image("What's Up?", padding_top_bottom=1, padding_left_right=3)
     Screen.show(demo, args=(image, 300, 0, "plasma", " ", False))
 
 
